package com.ruoyi.interfaces.mapper;

import java.util.List;

import com.ruoyi.common.annotation.DataSource;
import com.ruoyi.common.enums.DataSourceType;
import com.ruoyi.interfaces.domain.PtServiceReturn;
import org.apache.ibatis.annotations.Mapper;

/**
 * 返回数据Mapper接口
 * 
 * @author 朱得糠
 * @date 2025-08-29
 */
@DataSource(DataSourceType.SLAVE)
@Mapper
public interface PtServiceReturnMapper 
{
    /**
     * 查询返回数据
     * 
     * @param ID 返回数据主键
     * @return 返回数据
     */
    public PtServiceReturn selectPtServiceReturnByID(Long ID);

    /**
     * 查询返回数据列表
     * 
     * @param ptServiceReturn 返回数据
     * @return 返回数据集合
     */
    public List<PtServiceReturn> selectPtServiceReturnList(PtServiceReturn ptServiceReturn);

    /**
     * 新增返回数据
     * 
     * @param ptServiceReturn 返回数据
     * @return 结果
     */
    public int insertPtServiceReturn(PtServiceReturn ptServiceReturn);

    /**
     * 修改返回数据
     * 
     * @param ptServiceReturn 返回数据
     * @return 结果
     */
    public int updatePtServiceReturn(PtServiceReturn ptServiceReturn);

    /**
     * 删除返回数据
     * 
     * @param ID 返回数据主键
     * @return 结果
     */
    public int deletePtServiceReturnByID(Long ID);

    /**
     * 批量删除返回数据
     * 
     * @param IDs 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePtServiceReturnByIDs(Long[] IDs);

    int deletePtServiceReturnBySrvID(String srvId);
}
